{% extends "base.j2" %}

{% block main %}
  <article>
    <header>
      <h1>{{ title }}</h1>
      <time datetime="{{ date }}">{{ date }}</time>
    </header>
    {{ content }}
  </article>
{% endblock %}
